==> mako-config-0.2.0.tgz: package/test/index.js <==

'use strict';

let assert = require('chai').assert;
let config = require('..');
let path = require('path');

let fixture = path.resolve.bind(path, __dirname, 'fixtures');

describe('mako-config', function () {
  it('should resolve entries relative to the config file', function () {
    return config(fixture('simple/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, [ fixture('simple/index.html') ]);
    });
  });

  it('should resolve entries from glob patterns', function () {
    return config(fixture('glob/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, [
        fixture('glob/a.txt'),
        fixture('glob/b.txt'),
        fixture('glob/c.txt')
      ]);
    });
  });

  it('should prune out entries that do not exist', function () {
    return config(fixture('missing-entry/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, []);
    });
  });

  it('should allow the list of entries to be pre-empted', function () {
    return config(fixture('alternate-entries/mako.json'), [ 'index.md' ]).then(function (config) {
      assert.deepEqual(config.entries, [ fixture('alternate-entries/index.md') ]);
    });
  });

  it('should include an empty array of plugins if not specified', function () {
    return config(fixture('simple/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, []);
    });
  });

  it('should resolve plugins', function () {
    return config(fixture('plugin/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, [ 'vendor', 'local' ]);
    });
  });

  it('should pass arguments to plugins', function () {
    return config(fixture('plugin-options/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, [
        [ 'local', 'a', 'b', 'c' ]
      ]);
    });
  });

  context('with NODE_ENV', function () {
    beforeEach(function () {
      delete process.env.NODE_ENV;
    });

    it('should assume development when not otherwise specified', function () {
      return config(fixture('env/mako.json')).then(function (config) {
        assert.deepEqual(config.plugins, [ 'default', 'dev' ]);
      });
    });

    it('should merge extra config when a matching property exists', function () {
      process.env.NODE_ENV = 'production';

      return config(fixture('env/mako.json')).then(function (config) {
        assert.deepEqual(config.plugins, [ 'default', 'prod' ]);
      });
    });
  });
});

describe('sync', function () {
  it('should resolve entries relative to the config file', function () {
    let results = config.sync(fixture('simple/mako.json'));
    assert.deepEqual(results.entries, [ fixture('simple/index.html') ]);
  });

  it('should resolve entries from glob patterns', function () {
    let results = config.sync(fixture('glob/mako.json'));
    assert.deepEqual(results.entries, [
      fixture('glob/a.txt'),
      fixture('glob/b.txt'),
      fixture('glob/c.txt')
    ]);
  });

  it('should prune out entries that do not exist', function () {
    let results = config.sync(fixture('missing-entry/mako.json'));
    assert.deepEqual(results.entries, []);
  });

  it('should allow the list of entries to be pre-empted', function () {
    let results = config.sync(fixture('alternate-entries/mako.json'), [ 'index.md' ]);
    assert.deepEqual(results.entries, [ fixture('alternate-entries/index.md') ]);
  });

  it('should include an empty array of plugins if not specified', function () {
    let results = config.sync(fixture('simple/mako.json'));
    assert.deepEqual(results.plugins, []);
  });

  it('should resolve plugins', function () {
    let results = config.sync(fixture('plugin/mako.json'));
    assert.deepEqual(results.plugins, [ 'vendor', 'local' ]);
  });

  it('should pass arguments to plugins', function () {
    let results = config.sync(fixture('plugin-options/mako.json'));
    assert.deepEqual(results.plugins, [
      [ 'local', 'a', 'b', 'c' ]
    ]);
  });

  context('with NODE_ENV', function () {
    beforeEach(function () {
      delete process.env.NODE_ENV;
    });

    it('should assume development when not otherwise specified', function () {
      let results = config.sync(fixture('env/mako.json'));
      assert.deepEqual(results.plugins, [ 'default', 'dev' ]);
    });

    it('should merge extra config when a matching property exists', function () {
      process.env.NODE_ENV = 'production';

      let results = config.sync(fixture('env/mako.json'));
      assert.deepEqual(results.plugins, [ 'default', 'prod' ]);
    });
  });
});

==> mako-config-0.3.0.tgz: package/test/index.js <==

'use strict';

let assert = require('chai').assert;
let config = require('..');
let path = require('path');

let fixture = path.resolve.bind(path, __dirname, 'fixtures');

describe('mako-config', function () {
  it('should resolve entries relative to the config file', function () {
    return config(fixture('simple/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, [ fixture('simple/index.html') ]);
    });
  });

  it('should resolve entries from glob patterns', function () {
    return config(fixture('glob/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, [
        fixture('glob/a.txt'),
        fixture('glob/b.txt'),
        fixture('glob/c.txt')
      ]);
    });
  });

  it('should set a custom base when root specified', function () {
    return config(fixture('root/mako.json')).then(function (config) {
      let root = fixture('root/dir');
      assert.deepEqual(config.entries, [
        { base: root, path: fixture('root/dir/a.txt') },
        { base: root, path: fixture('root/dir/b.txt') },
        { base: root, path: fixture('root/dir/c.txt') }
      ]);
    });
  });

  it('should prune out entries that do not exist', function () {
    return config(fixture('missing-entry/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, []);
    });
  });

  it('should allow the list of entries to be pre-empted', function () {
    return config(fixture('alternate-entries/mako.json'), [ 'index.md' ]).then(function (config) {
      assert.deepEqual(config.entries, [ fixture('alternate-entries/index.md') ]);
    });
  });

  it('should include an empty array of plugins if not specified', function () {
    return config(fixture('simple/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, []);
    });
  });

  it('should resolve plugins', function () {
    return config(fixture('plugin/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, [ 'vendor', 'local' ]);
    });
  });

  it('should pass arguments to plugins', function () {
    return config(fixture('plugin-options/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, [
        [ 'local', 'a', 'b', 'c' ]
      ]);
    });
  });

  context('with NODE_ENV', function () {
    beforeEach(function () {
      delete process.env.NODE_ENV;
    });

    it('should assume development when not otherwise specified', function () {
      return config(fixture('env/mako.json')).then(function (config) {
        assert.deepEqual(config.plugins, [ 'default', 'dev' ]);
      });
    });

    it('should merge additional entries', function () {
      process.env.NODE_ENV = 'production';

      return config(fixture('env/mako.json')).then(function (config) {
        assert.deepEqual(config.entries, [ fixture('env/index.html'), fixture('env/production.js') ]);
      });
    });

    it('should merge additional plugins', function () {
      process.env.NODE_ENV = 'production';

      return config(fixture('env/mako.json')).then(function (config) {
        assert.deepEqual(config.plugins, [ 'default', 'prod' ]);
      });
    });

    it('should handle an empty env config without failing', function () {
      config(fixture('empty-env/mako.json')).then(function (config) {
        assert.deepEqual(config, {
          entries: [ fixture('empty-env/index.html') ],
          plugins: [ 'default' ]
        });
      });
    });
  });
});

describe('sync', function () {
  it('should resolve entries relative to the config file', function () {
    let results = config.sync(fixture('simple/mako.json'));
    assert.deepEqual(results.entries, [ fixture('simple/index.html') ]);
  });

  it('should resolve entries from glob patterns', function () {
    let results = config.sync(fixture('glob/mako.json'));
    assert.deepEqual(results.entries, [
      fixture('glob/a.txt'),
      fixture('glob/b.txt'),
      fixture('glob/c.txt')
    ]);
  });

  it('should set a custom base when root specified', function () {
    let results = config.sync(fixture('root/mako.json'));
    let root = fixture('root/dir');
    assert.deepEqual(results.entries, [
      { base: root, path: fixture('root/dir/a.txt') },
      { base: root, path: fixture('root/dir/b.txt') },
      { base: root, path: fixture('root/dir/c.txt') }
    ]);
  });

  it('should prune out entries that do not exist', function () {
    let results = config.sync(fixture('missing-entry/mako.json'));
    assert.deepEqual(results.entries, []);
  });

  it('should allow the list of entries to be pre-empted', function () {
    let results = config.sync(fixture('alternate-entries/mako.json'), [ 'index.md' ]);
    assert.deepEqual(results.entries, [ fixture('alternate-entries/index.md') ]);
  });

  it('should include an empty array of plugins if not specified', function () {
    let results = config.sync(fixture('simple/mako.json'));
    assert.deepEqual(results.plugins, []);
  });

  it('should resolve plugins', function () {
    let results = config.sync(fixture('plugin/mako.json'));
    assert.deepEqual(results.plugins, [ 'vendor', 'local' ]);
  });

  it('should pass arguments to plugins', function () {
    let results = config.sync(fixture('plugin-options/mako.json'));
    assert.deepEqual(results.plugins, [
      [ 'local', 'a', 'b', 'c' ]
    ]);
  });

  context('with NODE_ENV', function () {
    beforeEach(function () {
      delete process.env.NODE_ENV;
    });

    it('should assume development when not otherwise specified', function () {
      let results = config.sync(fixture('env/mako.json'));
      assert.deepEqual(results.plugins, [ 'default', 'dev' ]);
    });

    it('should merge additional entries', function () {
      process.env.NODE_ENV = 'production';

      let results = config.sync(fixture('env/mako.json'));
      assert.deepEqual(results.entries, [ fixture('env/index.html'), fixture('env/production.js') ]);
    });

    it('should merge additional plugins', function () {
      process.env.NODE_ENV = 'production';

      let results = config.sync(fixture('env/mako.json'));
      assert.deepEqual(results.plugins, [ 'default', 'prod' ]);
    });

    it('should handle an empty env config without failing', function () {
      let results = config.sync(fixture('empty-env/mako.json'));
      assert.deepEqual(results, {
        entries: [ fixture('empty-env/index.html') ],
        plugins: [ 'default' ]
      });
    });
  });
});
